@@ -25,7 +25,10 @@ SOFTWARE.
 """
 
 from aiohttp import ClientResponse
-from typing import Union
+from typing import Union, TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from .http import Route  # noqa
 
 
 class FortniteException(Exception):
@@ -69,6 +72,10 @@ class PartyError(FortniteException):
     pass
 
 
+class PartyIsFull(FortniteException):
+    """This exception is raised when the bot attempts to join a full party."""
+
+
 class Forbidden(FortniteException):
     """This exception is raised whenever you attempted a request that your
     account does not have permission to do.
@@ -126,6 +133,19 @@ class InviteeMaxFriendshipRequestsExceeded(FortniteException):
     pass
 
 
+class FriendOffline(FortniteException):
+    """This exception is raised when an action that requires a friend to be
+    online is performed at an offline friend.
+    """
+    pass
+
+
+class InvalidOffer(FortniteException):
+    """This exception is raised when an invalid/outdated offer is
+    passed. Only offers currently in the item shop are valid."""
+    pass
+
+
 class ValidationFailure(FortniteException):
     """Represents a validation failure returned.
 
