@@ -929,9 +929,14 @@ class HTTPClient:
             'captcha': ''
         }
 
+        cookies = {
+            'EPIC_COUNTRY': 'US'
+        }
+
         return await self.post(EpicGames('/id/api/login'),
                                headers=headers,
-                               data=payload)
+                               data=payload,
+                               cookies=cookies)
 
     async def epicgames_mfa_login(self, method: str,
                                   code: str,
@@ -992,13 +997,13 @@ class HTTPClient:
     #           User Search           #
     ###################################
 
-    async def user_search_by_prefix(self, prefix: str, platform: str) -> list:
+    async def user_search_by_prefix(self, client_id: str, prefix: str, platform: str) -> list:
         params = {
             'prefix': prefix,
             'platform': platform
         }
 
-        r = UserSearchService('/api/v1/search')
+        r = UserSearchService('/api/v1/search/{client_id}', client_id=client_id)
         return await self.get(r, params=params)
 
     ###################################
