@@ -3,7 +3,7 @@
 """
 MIT License
 
-Copyright (c) 2019-2020 Terbau
+Copyright (c) 2019-2021 Terbau
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -113,6 +113,9 @@ class UserBase:
         if data:
             self._update(data)
 
+    def __hash__(self) -> int:
+        return hash(self._id)
+
     def __str__(self) -> str:
         return self.display_name
 
@@ -123,14 +126,19 @@ class UserBase:
         return not self.__eq__(other)
 
     @property
-    def display_name(self) -> str:
-        """:class:`str`: The users displayname
+    def display_name(self) -> Optional[str]:
+        """Optional[:class:`str`]: The users displayname
 
         .. warning::
 
             The display name will be the one registered to the epicgames
             account. If an epicgames account is not found it defaults
             to the display name of an external auth.
+
+        .. warning::
+
+            This property might be ``None`` if
+            ``Client.fetch_user_data_in_events`` is set to ``False``.
         """
         return self._epicgames_display_name or self._external_display_name
 
@@ -158,6 +166,12 @@ class UserBase:
             If this is True, the display name will be the one registered to
             the epicgames account, if not it defaults to the display name of
             an external auth.
+
+        .. warning::
+
+            This property might be ``False`` even though the account is a
+            registered epic games account if
+            ``Client.fetch_user_data_in_events`` is set to ``False``.
         """
         return self._epicgames_display_name is not None
 
@@ -166,6 +180,26 @@ class UserBase:
         """:class:`aioxmpp.JID`: The JID of the user."""
         return JID.fromstr('{0.id}@{0.client.service_host}'.format(self))
 
+    async def fetch(self) -> None:
+        """|coro|
+
+        Fetches basic information about this user and sets the updated
+        properties. This might be useful if you for example need to be
+        sure the display name is updated or if you have
+        ``Client.fetch_user_data_in_events`` set to ``False``.
+
+        Raises
+        ------
+        HTTPException
+            An error occured while requesting.
+        """
+        result = await self.client.http.account_graphql_get_multiple_by_user_id(  # noqa
+            (self.id,),
+        )
+        data = result['accounts'][0]
+
+        self._update(data)
+
     async def fetch_br_stats(self, *,
                              start_time: Optional[DatetimeOrTimestamp] = None,
                              end_time: Optional[DatetimeOrTimestamp] = None
@@ -265,6 +299,12 @@ class UserBase:
         ----------
         season: :class:`int`
             The season number to request the battlepass level for.
+            
+            .. warning::
+
+                If you are requesting the previous season and the new season has not been
+                added to the library yet (check :class:`SeasonStartTimestamp`), you have to
+                manually include the previous seasons end timestamp in epoch seconds.
         start_time: Optional[Union[:class:`int`, :class:`datetime.datetime`, :class:`SeasonStartTimestamp`]]
             The UTC start time of the window to get the battlepass level from.
             *Must be seconds since epoch, :class:`datetime.datetime` or a constant from SeasonEndTimestamp*
@@ -305,11 +345,12 @@ class UserBase:
             extra_external_auths=data.get('extraExternalAuths', []),
         )
 
-        self._id = data.get('accountId',
-                            data.get('id', data.get('account_id')))
+        self._id = data.get('id', data.get('accountId', data.get('account_id')))  # noqa
 
     def _update_external_auths(self, external_auths: List[dict], *,
-                               extra_external_auths: List[dict] = []) -> None:
+                               extra_external_auths: Optional[List[dict]] = None  # noqa
+                               ) -> None:
+        extra_external_auths = extra_external_auths or []
         extra_ext = {v['authIds'][0]['type'].split('_')[0].lower(): v
                      for v in extra_external_auths}
 
